/* $Workfile: OtxToneD.h $   $Revision: 23 $    $Modtime: 2/25/02 11:39a $  */
#ifndef OTX_TONE_DEF_H
#define OTX_TONE_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxToneD

  Copyright (C) 1998, 1999 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxToneD | Constants, Macros, and Types for the HDLC Functions

  @contents2
  OtxToneD.h |

  @index enum type struct | OtxToneD

  @contents2
  OTX Tone Logical Data Filter Device Macros, Constants, and Types |

  @head3 OtxToneXXX Macro, Constant, and Type Reference |

  @index enum type struct | OtxToneD

*******************************************************************************/

#include "OtxType.h"
#include "OtxErr.h"

#ifdef __cplusplus
  extern "C" {
#endif

/*---------------------------------------------------------------------------*\
  @enum
    FSK Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxFskDetectorResultCodesE {
  OTX_FSK_DETECTOR_RES_END                  = OTX_RES_END +  1
};
typedef enum OtxFskDetectorResultCodesE OtxFskDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    FSK Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxFskDetectorEventCodesE {
  OTX_FSK_DETECTOR_EC_ALERT                = 0x00,
  OTX_FSK_DETECTOR_EC_COMPLETE             = 0x01,
  OTX_FSK_DETECTOR_EC_TIMEOUT              = 0x02,
  OTX_FSK_DETECTOR_EC_BYTE                 = 0x03,

  OTX_FSK_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxFskDetectorEventCodesE OtxFskDetectorEventCodesE;



/*---------------------------------------------------------------------------*\
  @enum
    DTMF Dialer Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDialerResultCodesE {
  OTX_DTMF_DIALER_RES_INVALID_DTMF_VALUE   = OTX_RES_END +  0 ,  // @emem Invalid DTMF value        
  OTX_DTMF_DIALER_RES_BUSY                 = OTX_RES_END +  1 ,  // @emem DTMF Dialer is busy
  OTX_DTMF_DIALER_RES_END                  = OTX_RES_END +  2
};
typedef enum OtxDtmfDialerResultCodesE OtxDtmfDialerResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    DTMF Dialer Event Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDialerEventCodesE {
  OTX_DTMF_DIALER_EC_COMPLETE            = 0x00,
    
  OTX_DTMF_DIALER_END_OF_EVENT_CODES
};
typedef enum OtxDtmfDialerEventCodesE OtxDtmfDialerEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Const Val Generator Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxConstValGeneratorResultCodesE {
  OTX_CONST_VAL_GENERATOR_RES_END     = OTX_RES_END +  0
};
typedef enum OtxConstValGeneratorResultCodesE OtxConstValGeneratorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Const Val Generator Event Codes
\*---------------------------------------------------------------------------*/
enum OtxConstValGeneratorEventCodesE {
    
  OTX_CONST_VAL_GENERATOR_END_OF_EVENT_CODES
};
typedef enum OtxConstValGeneratorEventCodesE OtxConstValGeneratorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Val Sampler Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxValSamplerResultCodesE {
  OTX_VAL_SAMPLER_RES_END     = OTX_RES_END +  0
};
typedef enum OtxValSamplerResultCodesE OtxValSamplerResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Val Sampler Event Codes
\*---------------------------------------------------------------------------*/
enum OtxValSamplerEventCodesE {
    
  OTX_VAL_SAMPLER_END_OF_EVENT_CODES
};
typedef enum OtxValSamplerEventCodesE OtxValSamplerEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Silence Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxSilenceDetectorResultCodesE {
  OTX_SILENCE_DETECTOR_RES_END     = OTX_RES_END +  0
};
typedef enum OtxSilenceDetectorResultCodesE OtxSilenceDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Silence Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxSilenceDetectorEventCodesE {
    
  OTX_SILENCE_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxSilenceDetectorEventCodesE OtxSilenceDetectorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    SineWave Generator Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxSineWaveGeneratorResultCodesE {
  OTX_SINEWAVE_GENERATOR_RES_END     = OTX_RES_END +  0
};
typedef enum OtxSineWaveGeneratorResultCodesE OtxSineWaveGeneratorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    SineWave Generator Event Codes
\*---------------------------------------------------------------------------*/
enum OtxSineWaveGeneratorEventCodesE {
    
  OTX_SINEWAVE_GENERATOR_END_OF_EVENT_CODES
};
typedef enum OtxSineWaveGeneratorEventCodesE OtxSineWaveGeneratorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum 
    DTMF Detector Attributes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDetectorAttributesE {
  OTX_ATTR_DTMF_DETECTOR_MIN_DURATION        = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read/Write. 
                                                                  // Minimum required duration (in milliseconds) of a tone
                                                                  // before it is reported as a detected tone.

  OTX_ATTR_DTMF_DETECTOR_END                 = OTX_ATTR_END + 1
};

typedef enum OtxDtmfDetectorAttributesE OtxDtmfDetectorAttributesE;


/*---------------------------------------------------------------------------*\
  @enum
    DTMF Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDetectorResultCodesE {
  OTX_DTMF_DETECTOR_RES_NO_TONE         = OTX_RES_END +  0 ,  // @emem No DTMF tone presently detected        
  OTX_DTMF_DETECTOR_RES_TONE            = OTX_RES_END +  1 ,  // @emem DTMF tone is presently detected        
  OTX_DTMF_DETECTOR_RES_END             = OTX_RES_END +  2
};
typedef enum OtxDtmfDetectorResultCodesE OtxDtmfDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    DTMF Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxDtmfDetectorEventCodesE {
  OTX_DTMF_DETECTOR_EC_DIGIT               = 0x00,  // @emem DTMF tone detected        
  OTX_DTMF_DETECTOR_EC_PAUSE               = 0x01,  // @emem Pause detected        
    
  OTX_DTMF_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxDtmfDetectorEventCodesE OtxDtmfDetectorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum 
    MF Dialer Attributes
\*---------------------------------------------------------------------------*/
enum OtxMfDialerAttributesE {
  OTX_ATTR_MF_DIALER_END                 = OTX_ATTR_END + 0
};
typedef enum OtxMfDialerAttributesE OtxMfDialerAttributesE;

/*---------------------------------------------------------------------------*\
  @enum
    MF Dialer Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxMfDialerResultCodesE {
  OTX_MF_DIALER_RES_INVALID_MF_VALUE     = OTX_RES_END +  0 ,  // @emem Invalid MF value        
  OTX_MF_DIALER_RES_BUSY                 = OTX_RES_END +  1 ,  // @emem MF Dialer is busy
  OTX_MF_DIALER_RES_END                  = OTX_RES_END +  2
};
typedef enum OtxMfDialerResultCodesE OtxMfDialerResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    MF Dialer Event Codes
\*---------------------------------------------------------------------------*/
enum OtxMfDialerEventCodesE {
  OTX_MF_DIALER_EC_COMPLETE            = 0x00,
    
  OTX_MF_DIALER_END_OF_EVENT_CODES
};
typedef enum OtxMfDialerEventCodesE OtxMfDialerEventCodesE;





/*---------------------------------------------------------------------------*\
  @enum 
    MF Detector Attributes
\*---------------------------------------------------------------------------*/
enum OtxMfDetectorAttributesE {
  OTX_ATTR_MF_DETECTOR_VERBOSE_STATUS            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_BOOL) Read/Write.
                                                                      // Used mainly for debugging. When set to OTX_TRUE
                                                                      // the MF detector will report energy level for tones
                                                                      // which failed to meet the criteria for a valid tone/digit
  OTX_ATTR_MF_DETECTOR_THRESHOLD_TONE_ENERGY     = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // Threshold for definite tone. The energy for two frequency components
                                                                      // if the tone must both be above this level to be considered as a candidate
                                                                      // for a detected MF tone.
  OTX_ATTR_MF_DETECTOR_THRESHOLD_PAUSE_ENERGY    = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // Threshold for pause energy. All frequency components must be below this
                                                                      // energy level to be considered as a pause (silence) between two tones.
  OTX_ATTR_MF_DETECTOR_THRESHOLD_TWIST           = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // Twist. MaxEnergy-2ndMaxEnergy must be less than this threshold to be considered
                                                                      // a candidate for a detected MF tone.
  OTX_ATTR_MF_DETECTOR_THRESHOLD_RELATIVE_3RD    = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // The energy level of the 2nd highest frequency component must be this must
                                                                      // larger than the the energy level of 3rd highest frequency component. 
                                                                      // I.e. 2ndMaxEnergy-3rdMaxEnergy must be greater than this threshold.
  OTX_ATTR_MF_DETECTOR_END                       = OTX_ATTR_END + 0
};

typedef enum OtxMfDetectorAttributesE OtxMfDetectorAttributesE;


/*---------------------------------------------------------------------------*\
  @enum
    MF Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxMfDetectorResultCodesE {
  OTX_MF_DETECTOR_RES_NO_TONE         = OTX_RES_END +  0 ,  // @emem No MF tone presently detected        
  OTX_MF_DETECTOR_RES_TONE            = OTX_RES_END +  1 ,  // @emem MF tone is presently detected        
  OTX_MF_DETECTOR_RES_END             = OTX_RES_END +  2
};
typedef enum OtxMfDetectorResultCodesE OtxMfDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    MF Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxMfDetectorEventCodesE {
  OTX_MF_DETECTOR_EC_DIGIT               = 0x00,  // @emem MF tone detected        
  OTX_MF_DETECTOR_EC_PAUSE               = 0x01,  // @emem Pause detected        
  OTX_MF_DETECTOR_EC_VERBOSE_STATUS      = 0x02,  // @emem Decode status        
    
  OTX_MF_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxMfDetectorEventCodesE OtxMfDetectorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum 
    Dual Tone Detector Attributes
\*---------------------------------------------------------------------------*/
enum OtxDualToneDetectorAttributesE {
  OTX_ATTR_DUAL_TONE_DETECTOR_VERBOSE_STATUS            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_BOOL) Read/Write.
                                                                      // Used mainly for debugging. When set to OTX_TRUE
                                                                      // the MF detector will report energy level for tones
                                                                      // which failed to meet the criteria for a valid tone/digit
  OTX_ATTR_DUAL_TONE_DETECTOR_THRESHOLD_TONE_ENERGY     = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // Threshold for definite tone. The energy for two frequency components
                                                                      // if the tone must both be above this level to be considered as a candidate
                                                                      // for a detected MF tone.
  OTX_ATTR_DUAL_TONE_DETECTOR_THRESHOLD_PAUSE_ENERGY    = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // Threshold for pause energy. All frequency components must be below this
                                                                      // energy level to be considered as a pause (silence) between two tones.
  OTX_ATTR_DUAL_TONE_DETECTOR_THRESHOLD_TWIST           = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // Twist. MaxEnergy-2ndMaxEnergy must be less than this threshold to be considered
                                                                      // a candidate for a detected MF tone.
  OTX_ATTR_DUAL_TONE_DETECTOR_THRESHOLD_RELATIVE_3RD    = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read/Write.
                                                                      // The energy level of the 2nd highest frequency component must be this must
                                                                      // larger than the the energy level of 3rd highest frequency component. 
                                                                      // I.e. 2ndMaxEnergy-3rdMaxEnergy must be greater than this threshold.
  OTX_ATTR_DUAL_TONE_DETECTOR_END                       = OTX_ATTR_END + 0
};

typedef enum OtxDualToneDetectorAttributesE OtxDualToneDetectorAttributesE;


/*---------------------------------------------------------------------------*\
  @enum
    MF Detector Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxDualToneDetectorResultCodesE {
  OTX_DUAL_TONE_DETECTOR_RES_NO_TONE         = OTX_RES_END +  0 ,  // @emem No Dual tone presently detected        
  OTX_DUAL_TONE_DETECTOR_RES_TONE            = OTX_RES_END +  1 ,  // @emem Dual tone is presently detected        
  OTX_DUAL_TONE_DETECTOR_RES_END             = OTX_RES_END +  2
};
typedef enum OtxDualToneDetectorResultCodesE OtxDualToneDetectorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    MF Detector Event Codes
\*---------------------------------------------------------------------------*/
enum OtxDualToneDetectorEventCodesE {
  OTX_DUAL_TONE_DETECTOR_EC_TONE                = 0x00,  // @emem Dual tone detected        
  OTX_DUAL_TONE_DETECTOR_EC_PAUSE               = 0x01,  // @emem Pause detected        
  OTX_DUAL_TONE_DETECTOR_EC_VERBOSE_STATUS      = 0x02,  // @emem Decode status        
    
  OTX_DUAL_TONE_DETECTOR_END_OF_EVENT_CODES
};
typedef enum OtxDualToneDetectorEventCodesE OtxDualToneDetectorEventCodesE;




/*---------------------------------------------------------------------------*\
  @enum
    Effects Generator Error Result Codes
\*---------------------------------------------------------------------------*/
enum OtxEffectsGeneratorResultCodesE {
  OTX_EFFECTS_GENERATOR_RES_END                  = OTX_RES_END +  1
};
typedef enum OtxEffectsGeneratorResultCodesE OtxEffectsGeneratorResultCodesE;

/*---------------------------------------------------------------------------*\
  @enum
    Effects Generator Event Codes
\*---------------------------------------------------------------------------*/
enum OtxEffectsGeneratorEventCodesE {
  // None 
  OTX_EFFECTS_GENERATOR_END_OF_EVENT_CODES
};
typedef enum OtxEffectsGeneratorEventCodesE OtxEffectsGeneratorEventCodesE;



// @enum Type of tone effect to be generated
enum OtxToneEffectE {
  OTX_TONE_SINEWAVE      = 0,  // @emem 1kHz sinusoidal wave
  OTX_TONE_SAWTOOTH      = 1,  // @emem Ramp wave
  OTX_TONE_SWEEPING_SINE = 2,  // @emem Variable frequency sinusoidal wave
  OTX_TONE_NOISE         = 3,  // @emem Random noise
  OTX_TONE_BYTE_VARIABLE = 4   // @emem Sequential bytes: 0, 1, 2, ..., 255, 0, 1, ...
};

typedef enum OtxToneEffectE OtxToneEffectE;


// @enum Type of MF (Multi Frequency) tone 
enum OtxMfToneE {
  OTX_TONE_MF_UNKNOWN     = 0,  // @emem Invalid value 
  OTX_TONE_MF_R1          = 1,  // @emem CCITT R1 MF tones:
	    	                        // <nl>  0:  0   (1300Hz/1500Hz)	 
                                // <nl>  1:  1   (700Hz/900Hz)	
                                // <nl>  2:  2   (700Hz/1100Hz)	
                                // <nl>  3:  3   (900Hz/1100Hz)	
                                // <nl>  4:  4   (700Hz/1300Hz)	
                                // <nl>  5:  5   (900Hz/1300Hz)	
	    	                        // <nl>  6:  6   (1100Hz/1300Hz)	
                                // <nl>  7:  7   (700Hz/1500Hz)	
                                // <nl>  8:  8   (900Hz/1500Hz)	
	    	                        // <nl>  9:  9   (1100Hz/1500Hz)	
	    	                        // <nl> 10: KP   (1100Hz/1700Hz)	
	    	                        // <nl> 11: ST   (1500Hz/1700Hz)	
                                // <nl> 12: ST1  (900Hz/1700Hz)	
                                // <nl> 13: ST2  (1300Hz/1700Hz)
                                // <nl> 14: ST3  (700Hz/1700Hz)	
  OTX_TONE_MF_R2_FORWARD  = 2,  // @emem CCITT R2 MF Forward tones:
	    	                        // <nl>  1:      (1380Hz/1500Hz)
	    	                        // <nl>  2:      (1380Hz/1620Hz)
	    	                        // <nl>  3:      (1500Hz/1620Hz)
	    	                        // <nl>  4:      (1380Hz/1740Hz)
	    	                        // <nl>  5:      (1500Hz/1740Hz)
	    	                        // <nl>  6:      (1620Hz/1740Hz)
	    	                        // <nl>  7:      (1380Hz/1860Hz)
	    	                        // <nl>  8:      (1500Hz/1860Hz)
	    	                        // <nl>  9:      (1620Hz/1860Hz)
	    	                        // <nl> 10:      (1740Hz/1860Hz)
	    	                        // <nl> 11:      (1380Hz/1980Hz)
	    	                        // <nl> 12:      (1500Hz/1980Hz)
	    	                        // <nl> 13:      (1620Hz/1980Hz)
	    	                        // <nl> 14:      (1740Hz/1980Hz)
	    	                        // <nl> 15:      (1860Hz/1980Hz)
                                                                                    

  OTX_TONE_MF_R2_BACKWARD = 3,  // @emem CCITT R2 MF Backward tones:
	    	                        // <nl>  1:      (1140Hz/1020Hz)
	    	                        // <nl>  2:      (1140Hz/900Hz)
	    	                        // <nl>  3:      (1020Hz/900Hz)
	    	                        // <nl>  4:      (1140Hz/780Hz)
	    	                        // <nl>  5:      (1020Hz/780Hz)
	    	                        // <nl>  6:      (900Hz/780Hz)
	    	                        // <nl>  7:      (1140Hz/660Hz)
	    	                        // <nl>  8:      (1020Hz/660Hz)
	    	                        // <nl>  9:      (900Hz/660Hz)
	    	                        // <nl> 10:      (780Hz/660Hz)
	    	                        // <nl> 11:      (1140Hz/540Hz)
	    	                        // <nl> 12:      (1020Hz/540Hz)
	    	                        // <nl> 13:      (900Hz/540Hz)
	    	                        // <nl> 14:      (780Hz/540Hz)
	    	                        // <nl> 15:      (660Hz/540Hz)
};

typedef enum OtxMfToneE OtxMfToneE;


// @enum Gain of generated tones
enum OtxToneGainE {
  OTX_TONE_GAIN_0DB           = 0,  // @emem Full Gain
  OTX_TONE_GAIN_DG_MINUS_3DB  = 1,  // @emem -3dB Gain
  OTX_TONE_GAIN_DG_MINUS_6DB  = 2,  // @emem -6dB Gain
  OTX_TONE_GAIN_DG_MINUS_9DB  = 3,  // @emem -9dB Gain
  OTX_TONE_GAIN_DG_MINUS_12DB = 4,  // @emem -12dB Gain
  OTX_TONE_GAIN_DG_MINUS_15DB = 5   // @emem -15dB Gain
};

typedef enum OtxToneGainE OtxToneGainE;


/*******************************************************************************
  @struct
    Characteristics of a sinewave tone component. Tones containing multiple 
    frequency component can be generated by using an array of 
    this struct (see <f OtxToneSineWaveGeneratorInit>).
  @xref
   <f OtxToneSineWaveGeneratorInit>
*******************************************************************************/
struct OtxToneSineWaveDataS {
  OTX_FP64  nFrequency;    // @field Frequency of sinewave component
  OTX_FP64  nAttenuation;  // @field Attenuation of sinewave amplitude (in dB). E.g. 0dB is maximum amplitude, -3dB is 50% of maximum amplitude, -9dB is 25% of maximum amplitude.
  OTX_FP64  nPhase;        // @field Phase (in degrees) in relation to other sinewave tone components.
};

typedef struct OtxToneSineWaveDataS OtxToneSineWaveDataS;



#ifdef __cplusplus
  } // extern "C"
#endif


/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998, 1999


  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif // OTX_TONE_DEF_H
